| Title: | Database of Somatic Flags |
|---|---|
| Description: | Database of genes which frequently sustain somatic mutations, but are unlikely to drive cancer. |
| Authors: | Sam El-Kamand [aut, cre] (ORCID: <https://orcid.org/0000-0003-2270-8088>), Children's Cancer Institute Australia [cph] |
| Maintainer: | Sam El-Kamand <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-05-27 10:40:15 UTC |
| Source: | https://github.com/CCICB/somaticflags |
a list of genes which are frequently mutated in somatic cancer datasets but are unlikely to drive disease.
somaticflagssomaticflags
A vector with 139 gene names:
doi:10.1038/nature12213 and doi:10.1186/s12920-014-0064-y
data(somaticflags) head(somaticflags)data(somaticflags) head(somaticflags)
a list of genes which are frequently mutated in somatic cancer datasets but are unlikely to drive disease.
somaticflags_dfsomaticflags_df
A data.frame with 139 gene names:
Genes frequently mutated in somatic cancer datasets but that are unlikely to drive disease
Supporting papers for the gene being a somatic flag
Explanation for the gene being considered a somatic flag
...
doi:10.1038/nature12213 and doi:10.1186/s12920-014-0064-y
data(somaticflags_df) head(somaticflags_df)data(somaticflags_df) head(somaticflags_df)